<?php
namespace MascotCoreInsolanElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Accordion extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-accordion';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Accordion', 'mascot-core-insolan-wp-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'tm-elementor-widget-icon';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'mascot-core-insolan-wp-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'custom_css_class',
			[
				'label' => esc_html__( "Custom CSS class", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'display_type', [
				'label' => esc_html__( "Behavior", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'accordion' =>  esc_html__( 'Accordion', 'mascot-core-insolan-wp-elementor' ),
					'toggle'  =>  esc_html__( 'Toggle', 'mascot-core-insolan-wp-elementor' ),
				],
				'default' => 'accordion'
			]
		);
		$this->add_control(
			'design', [
				'label' => esc_html__( "Design", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'' =>  esc_html__( 'Basic', 'mascot-core-insolan-wp-elementor' ),
					'accordion-classic'  =>  esc_html__( 'Classic', 'mascot-core-insolan-wp-elementor' ),
					'accordion-gradient'  =>  esc_html__( 'Gradient', 'mascot-core-insolan-wp-elementor' ),
					'accordion-active-light'  =>  esc_html__( 'Light Color on Active', 'mascot-core-insolan-wp-elementor' ),
				],
				'default' => ''
			]
		);
		$this->add_control(
			'theme-color', [
				'label' => esc_html__( "Theme Color", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'' =>  esc_html__( 'Default', 'mascot-core-insolan-wp-elementor' ),
					'accordion-theme-colored1'  =>  esc_html__( 'Theme Color 1', 'mascot-core-insolan-wp-elementor' ),
					'accordion-theme-colored2'  =>  esc_html__( 'Theme Color 2', 'mascot-core-insolan-wp-elementor' ),
					'accordion-theme-colored3'  =>  esc_html__( 'Theme Color 3', 'mascot-core-insolan-wp-elementor' ),
					'accordion-theme-colored4'  =>  esc_html__( 'Theme Color 4', 'mascot-core-insolan-wp-elementor' ),
				],
				'default' => ''
			]
		);
		$repeater = new \Elementor\Repeater();

		$repeater->add_control(
			'title',
			[
				'label' => esc_html__( "Title", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$repeater->add_control(
			'title_tag',
			[
				'label' => esc_html__( "Title Tag", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_insolan_heading_tag_list(),
				'default' => 'h5',
			]
		);
		$repeater->add_control(
			'expand',
			[
				'label' => esc_html__( "Make Expand?", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'no'
			]
		);
		$repeater->add_control(
			'content',
			[
				'label' => esc_html__( "Description", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => esc_html__( "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.", 'mascot-core-insolan-wp-elementor' ),
			]
		);


		$this->add_control(
			'accordion_items',
			[
				'label' => esc_html__( "Item", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
			]
		);
		$this->end_controls_section();







		$this->start_controls_section(
			'custom_styling',
			[
				'label' => esc_html__( 'Custom Styling', 'mascot-core-insolan-wp-elementor' ),
				'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'border_radius',
			[
				'label' => esc_html__( "Border Radius", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'selectors' => [
					'{{WRAPPER}} .tm-accordion .card' => 'border-radius: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'margin_bottom',
			[
				'label' => esc_html__( "Margin Bottom", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'selectors' => [
					'{{WRAPPER}} .tm-accordion .card:not(:last-child)' => 'margin-bottom: {{VALUE}};'
				]
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'wrapper_boxshadow',
				'label' => esc_html__( 'Box Shadow', 'mascot-core-insolan-wp-elementor' ),
				'selector' => '{{WRAPPER}} .tm-accordion .card',
			]
		);
		$this->end_controls_section();






		$this->start_controls_section(
			'title_options',
			[
				'label' => esc_html__( 'Title Options', 'mascot-core-insolan-wp-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_group_control(
			\Elementor\Group_Control_Typography::get_type(),
			[
				'name' => 'title_typography',
				'label' => esc_html__( 'Title Typography', 'mascot-core-insolan-wp-elementor' ),
				'selector' => '{{WRAPPER}} .card-header .title',
			]
		);
		$this->add_control(
			'title_text_color',
			[
				'label' => esc_html__( "Title Text Color", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .card-header .title' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'title_text_color_hover',
			[
				'label' => esc_html__( "Title Text Color (Hover)", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}}:hover .card-header .title' => 'color: {{VALUE}};'
				]
			]
		);
		$this->add_control(
			'title_theme_colored',
			[
				'label' => esc_html__( "Title Theme Colored", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => insolan_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}} .card-header .title' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->add_control(
			'title_theme_colored_hover',
			[
				'label' => esc_html__( "Title Theme Colored (Hover)", 'mascot-core-insolan-wp-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => insolan_mascot_theme_color_list(),
				'default' => '',
				'selectors' => [
					'{{WRAPPER}}:hover .card-header .title' => 'color: var(--theme-color{{VALUE}});'
				],
			]
		);
		$this->end_controls_section();
	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$html = '';
		$settings = $this->get_settings_for_display();
		
		//classes
		$classes = array();
		$classes[] = 'tm-accordion';
		$classes[] = $settings['custom_css_class'];
		$classes[] = $settings['display_type'];
		$classes[] = $settings['design'];
		$classes[] = $settings['theme-color'];

		$settings['classes'] = $classes;

		$settings['holder_id'] = insolan_mascot_get_isotope_holder_ID('accordion');
	?>
		<div id="<?php echo esc_attr( $settings['holder_id'] ) ?>" class="<?php echo esc_attr(implode(' ', $classes)); ?>">
	<?php
		if ( $settings['accordion_items'] ) { 
			$rand = rand(10,100);
			$i=1;
			foreach (  $settings['accordion_items'] as $item ) {
				$item['rand'] = $rand.''.$i;
				$item['holder_id'] = $settings['holder_id'];
				//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
				$html .= mascot_core_insolan_elementor_get_shortcode_template_part( $settings['display_type'], null, 'accordion/tpl', $item, true );
				$i++;
			}
		} 
		echo $html;
	?>
		</div>
	<?php
	}
}